AutoGen Assistant | Home

Agents
Select or create an agent workflow.
Agent Workflow
Settings
General Agent Workflow
Sessions
Create a new session or select an existing session to view chat.
No sessions found. Create a new session to get started.
Skills
Skills are python functions that agents can use to solve tasks.

Clear Conversation
close sidebar
Blank slate? Try one of the example prompts below
Maintained by the AutoGen Team.